@@ -6,7 +6,7 @@ function (X, ...)
     X <- as.wmppp.ppp(X, ...)
   
   # Get the distance matrix
-  Dmatrix <- spatstat::pairdist(X)
+  Dmatrix <- spatstat.geom::pairdist(X)
   
   # Convert
   return (Dtable(Dmatrix, PointType=X$marks$PointType , PointWeight=X$marks$PointWeight))
